Name:           ocaml-zarith
Version:        1.14
Release:        %mkrel 2
Summary:        OCaml interface to GMP
License:        LGPLv2 with exceptions
Group:          Development/OCaml
URL:            https://github.com/ocaml/Zarith/
Source0:        https://github.com/ocaml/Zarith/archive/release-%{version}.tar.gz

BuildRequires:  pkgconfig(gmp)
BuildRequires:  ocaml >= 4.04.0
BuildRequires:  ocaml-findlib
BuildRequires:  ocaml-ocamldoc
BuildRequires:  ocaml-rpm-macros

# Do not require ocaml-compiler-libs at runtime
%global __ocaml_requires_opts -i Asttypes -i Build_path_prefix_map -i Cmi_format -i Env -i Format_doc -i Ident -i Identifiable -i Load_path -i Location -i Longident -i Misc -i Oprint -i Outcometree -i Parsetree -i Path -i Primitive -i Shape -i Subst -i Toploop -i Type_immediacy -i Types -i Unit_info -i Warnings

%description
This library implements arithmetic and logical operations over
arbitrary-precision integers.

The module is simply named "Z".  Its interface is similar to that of the
Int32, Int64 and Nativeint modules from the OCaml standard library, with
some additional functions.  See the file z.mlip for documentation.

The implementation uses GMP (the GNU Multiple Precision arithmetic
library) to compute over big integers.  However, small integers are
represented as unboxed Caml integers, to save space and improve
performance.  Big integers are allocated in the Caml heap, bypassing
GMP's memory management and achieving better GC behavior than e.g. the
MLGMP library.  Computations on small integers use a special, faster
path (coded in assembly for some platforms and functions) eschewing
calls to GMP, while computations on large integers use the low-level
MPN functions from GMP.

Arbitrary-precision integers can be compared correctly using OCaml's
polymorphic comparison operators (=, <, >, etc.).

Additional features include:
- a module Q for rationals, built on top of Z (see q.mli)
- a compatibility layer Big_int_Z that implements the same API as Big_int,
  but uses Z internally

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       pkgconfig(gmp)

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%autosetup -n Zarith-release-%{version}

%conf
# Fix compilation flags
sed -i "s|^ccdef=''|ccdef='%{build_cflags}'|" configure
sed -i "s/-shared/-g &/" project.mak

%build
export CC="gcc"
# This is NOT an autoconf-generated configure script; %%configure doesn't work
./configure
# %%{?_smp_mflags} is not safe; same action performed by multiple CPUs
make
make doc

%install
mkdir -p %{buildroot}%{ocamldir}/stublibs
make install INSTALLDIR=%{buildroot}%{ocamldir}

# Install missing files
cp -p {big_int_Z,q,z}.cmt zarith_version.cm{i,t} zarith_top.{cm{i,t},ml} \
      z_mlgmpidl.mli %{buildroot}%{ocamldir}/zarith
cp -p zarith.opam %{buildroot}%{ocamldir}/zarith/opam

%ocaml_files

%ifarch %{ocaml_native_compiler}
# The tests assume the availability of ocamlopt
%check
export LD_LIBRARY_PATH=$PWD
make tests
%endif

%files -f .ofiles
%doc README.md
%license LICENSE

%files devel -f .ofiles-devel
%doc Changes html



%changelog
* Mon Jul 07 2025 umeabot <umeabot> 1.14-2.mga10
+ Revision: 2251017
- Mageia 10 Mass Rebuild

* Tue Apr 08 2025 pterjan <pterjan> 1.14-1.mga10
+ Revision: 2174239
- Update to 1.14

* Fri Jan 06 2023 papoteur <papoteur> 1.12-4.mga9
+ Revision: 1930809
- restore build of dllzarith.so

* Wed May 18 2022 pterjan <pterjan> 1.12-3.mga9
+ Revision: 1858779
- Rebuild for OCaml 4.14

* Tue Mar 29 2022 umeabot <umeabot> 1.12-2.mga9
+ Revision: 1832508
- Mageia 9 Mass Rebuild

* Wed Oct 13 2021 tv <tv> 1.12-1.mga9
+ Revision: 1750938
- 1.12 + Rebuild for ocaml 4.13.1

* Thu Mar 04 2021 tv <tv> 1.11-1.mga9
+ Revision: 1697723
- 1.12

* Thu Mar 04 2021 tv <tv> 1.9.1-5.mga9
+ Revision: 1697714
- rebuild for ocaml-4.2-12

* Sat Aug 22 2020 tv <tv> 1.9.1-4.mga8
+ Revision: 1617815
- fix build
- Rebuild for new ocaml deps generator

* Fri Feb 28 2020 umeabot <umeabot> 1.9.1-3.mga8
+ Revision: 1551175
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 1.9.1-2.mga8
+ Revision: 1544194
- Mageia 8 Mass Rebuild

* Fri Jan 24 2020 tv <tv> 1.9.1-1.mga8
+ Revision: 1482693
- new release + rebuild for ocaml-4.10

* Tue Oct 23 2018 tv <tv> 1.7-4.mga7
+ Revision: 1324069
- rebuild with ocaml-4.07.1

* Mon Oct 22 2018 pterjan <pterjan> 1.7-3.mga7
+ Revision: 1323784
- Rebuild for ocaml 4.07

* Sun Sep 23 2018 umeabot <umeabot> 1.7-2.mga7
+ Revision: 1299951
- Mageia 7 Mass Rebuild

* Sun Mar 25 2018 daviddavid <daviddavid> 1.7-1.mga7
+ Revision: 1212392
- new version: 1.7
- update URL and Source URL

* Sun Nov 26 2017 tv <tv> 1.4.1-4.mga7
+ Revision: 1179789
- rebuild for new ocaml

* Sun Nov 26 2017 tv <tv> 1.4.1-3.mga7
+ Revision: 1179643
- rebuild for new ocaml

* Thu Aug 31 2017 daviddavid <daviddavid> 1.4.1-2.mga7
+ Revision: 1150071
- honor user CFLAGS thus fixing empty debugsourcefiles.list
- fix shared stubs libraries ocaml path

* Tue Feb 02 2016 pterjan <pterjan> 1.4.1-1.mga6
+ Revision: 931871
- Update to 1.4.1

* Wed Oct 15 2014 umeabot <umeabot> 1.2.1-5.mga5
+ Revision: 744247
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2.1-4.mga5
+ Revision: 683135
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.2.1-3.mga4
+ Revision: 536381
- Mageia 4 Mass Rebuild

* Mon Sep 23 2013 blue_prawn <blue_prawn> 1.2.1-2.mga4
+ Revision: 484186
- rebuild for ocaml-4.01.0

* Sat Jun 29 2013 malo <malo> 1.2.1-1.mga4
+ Revision: 448359
- update to 1.2.1

* Sun Jan 13 2013 umeabot <umeabot> 1.1-5.mga3
+ Revision: 361730
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 01 2012 blue_prawn <blue_prawn> 1.1-4.mga3
+ Revision: 301099
- rebuild for ocaml-4.00.0

* Sat Sep 29 2012 blue_prawn <blue_prawn> 1.1-3.mga3
+ Revision: 300353
- new rpm group for ocaml

* Mon Apr 09 2012 malo <malo> 1.1-2.mga2
+ Revision: 229851
- adding missing requires to gmp-devel

* Sun Mar 25 2012 blue_prawn <blue_prawn> 1.1-1.mga2
+ Revision: 226246
- imported package ocaml-zarith

